@@ -180,6 +180,7 @@ class Sushy(base.ResourceBase):
         if auth is None:
             auth = sushy_auth.SessionOrBasicAuth(username=username,
                                                  password=password)
+        self._auth = auth
 
         super(Sushy, self).__init__(
             connector or sushy_connector.Connector(base_url, verify=verify),
@@ -187,7 +188,6 @@ class Sushy(base.ResourceBase):
         self._public_connector = public_connector or requests
         self._language = language
         self._base_url = base_url
-        self._auth = auth
         self._auth.set_context(self, self._conn)
         self._auth.authenticate()
 
@@ -365,6 +365,16 @@ class Sushy(base.ResourceBase):
             self._conn, self._session_service_path,
             redfish_version=self.redfish_version)
 
+    def get_sessions_path(self):
+        """Returns the Sessions url"""
+
+        try:
+            links_url = self.json.get('Links')
+            return links_url['Sessions']['@odata.id']
+        except (TypeError, KeyError):
+            raise exceptions.MissingAttributeError(
+                attribute='Links/Sessions/@data.id', resource=self.path)
+
     def get_session(self, identity):
         """Given the identity return a Session object
 
